@@ -10,7 +10,7 @@ $OUTPUT_AUTOFLUSH=1;
 
  
 use vars qw($VERSION);
-$VERSION = '0.4';
+$VERSION = '0.41';
 
 my $VERBOSE = 0;
 
@@ -190,11 +190,11 @@ sub edge {
 	}
 	else {
 		if (exists($self->{graph}{$sourceID}{edges}{$targetID})) {
-			return($self->{graph}{$sourceID}{edges}{$targetID});
+			return( {sourceID=>$sourceID, targetID=>$targetID, weight=>$self->{graph}{$sourceID}{edges}{$targetID} } );
 		}
 	
 		if (exists($self->{graph}{$sourceID}) and exists($self->{graph}{$targetID})) {
-			return 0;
+			return( {sourceID=>$sourceID, targetID=>$targetID, weight=>0} );
 		}
 		
 		if (!exists($self->{graph}{$sourceID})) {
@@ -511,7 +511,7 @@ sub farthestNode {  ## no critic (ProhibitExcessComplexity)
 				
 			foreach my $i (0 .. $nexttolast) {
 				
-				push(@{$solutionHref->{path}{$solutioncnt}{edges}}, {sourceID => $path[$i], targetID => $path[$i+1], weight => $self->edge( { sourceID=>$path[$i], targetID=>$path[$i+1] } ) } );
+				push(@{$solutionHref->{path}{$solutioncnt}{edges}}, {sourceID => $path[$i], targetID => $path[$i+1], weight => $self->edge( { sourceID=>$path[$i], targetID=>$path[$i+1] } )->{weight} } );
 				
 			}
 		}
@@ -635,7 +635,7 @@ sub shortestPath { ## no critic (ProhibitExcessComplexity)
 		
 		my $nexttolast = $#path - 1;
 		foreach my $i (0 .. $nexttolast) {
-			push(@{$solutionHref->{edges}}, {sourceID => $path[$i], targetID => $path[$i+1], weight => $self->edge( { sourceID=>$path[$i], targetID=>$path[$i+1] } ) } );
+			push(@{$solutionHref->{edges}}, {sourceID => $path[$i], targetID => $path[$i+1], weight => $self->edge( { sourceID=>$path[$i], targetID=>$path[$i+1] } )->{weight} } );
 		}
 	}
 	return($pathWeight);
@@ -1729,7 +1729,8 @@ Graph::Dijkstra - Dijkstra's shortest path algorithm with methods to input/outpu
   my $nodeAttribs = $graph->node( 0 );  #returns hash reference (eg., $nodeAttribs->{id}, $nodeAttribs->{label}) or undef if node id 0 not found
   my $nodeLabel = $graph->node( 0 )->{label}; #references label attribute of node with ID value of 0
   my $bool = $graph->nodeExists( 0 );
-  my $edgeWeight = $graph->edge( { sourceID=>0, targetID=>1} );
+  my $edgeAttribs = $graph->edge( { sourceID=>0, targetID=>1} );
+  my $edgeWeight = $graph->edge( { sourceID=>0, targetID=>1} )->{weight};  #references weight attribute of edge that connects sourceID to targetID
   my $bool = $graph->edgeExists( { sourceID=>0, targetID=>1 } );
   my @nodes = $graph->nodeList();  #returns array of all nodes in the internal graph, each array element is a hash (reference) containing the node ID and label attributes
   my $bool = $graph->adjacent( { sourceID=>0, targetID=>1 } );
@@ -1895,10 +1896,11 @@ Removes node identified by $id and all connecting edges and returns self.  Retur
 SET method: creates or updates existing edge between $sourceID and $targetID and returns $self. $weight must be > 0. 
 Returns undef if $weight <= 0 or if $sourceID or $targetID do not exist.
 									 
-=item $graph->edge( {sourceID=>$sourceID, targetID=>$targetID} );
+=item my $graphAtrribs = $graph->edge( {sourceID=>$sourceID, targetID=>$targetID} );
 
-GET method: returns existing weight (cost/value/distance) of edge between $sourceID and $targetID.  Returns 0 if there is no edge between $sourceID and $targetID.
-Returns undef if $sourceID or $targetID do not exist. 											 
+GET method: returns hash reference with three attributes: sourceID, targetID, and weight (cost/distance/value of edge between sourceID and targetID).  
+"weight" is 0 if there is no edge between sourceID and targetID (and sourceID and targetID both exist).
+Returns undef if sourceID or targetID do not exist. 											 
  
 =item my $bool = $graph->edgeExists( { sourceID=>$sourceID, targetID=>$targetID } );
  
@@ -2291,6 +2293,9 @@ sequentially numbered IDs that are output.  This preserves the graph node and ed
 	o Always bug fixes.
 	o Updated test scripts.
 	
+=head2 Version 0.41
+
+	o Updated edge (GET) method to return a hash reference with three attributes: sourceID, targetID, and weight.
 
 =head1 PLATFORM DEPENDENCIES
 
